==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/tao/Special_Basic_Argument_T.cpp <==
// Special_Basic_Argument_T.cpp,v 1.2 2003/10/28 18:29:20 bala Exp

#ifndef TAO_SPECIAL_BASIC_ARGUMENT_T_C
#define TAO_SPECIAL_BASIC_ARGUMENT_T_C

#include "tao/Special_Basic_Argument_T.h"
#include "tao/Dynamic_ParameterC.h"

#if !defined (__ACE_INLINE__)
#include "tao/Special_Basic_Argument_T.inl"
#endif /* __ACE_INLINE__ */

ACE_RCSID (tao,
           Special_Basic_Argument_T,
           "Special_Basic_Argument_T.cpp,v 1.2 2003/10/28 18:29:20 bala Exp")

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::In_Special_Basic_Argument_T<S,to_S,from_S>::marshal (TAO_OutputCDR & cdr)
{
  return cdr << from_S (this->x_);
}

template<typename S, typename to_S, typename from_S>
void
TAO::In_Special_Basic_Argument_T<S,to_S,from_S>::interceptor_param (
    Dynamic::Parameter & p
  )
{
  p.argument <<= from_S (this->x_);
  p.mode = CORBA::PARAM_IN;
}

// ===========================================================

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::Inout_Special_Basic_Argument_T<S,to_S,from_S>::marshal (
    TAO_OutputCDR & cdr
  )
{
  return cdr << from_S (this->x_);
}

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::Inout_Special_Basic_Argument_T<S,to_S,from_S>::demarshal (
    TAO_InputCDR & cdr
  )
{
  return cdr >> to_S (this->x_);
}

template<typename S, typename to_S, typename from_S>
void
TAO::Inout_Special_Basic_Argument_T<S,to_S,from_S>::interceptor_param (
    Dynamic::Parameter & p
  )
{
  p.argument <<= from_S (this->x_);
  p.mode = CORBA::PARAM_INOUT;
}

// ==============================================================

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::Out_Special_Basic_Argument_T<S,to_S,from_S>::demarshal (
    TAO_InputCDR & cdr
  )
{
  return cdr >> to_S (this->x_);
}

template<typename S, typename to_S, typename from_S>
void
TAO::Out_Special_Basic_Argument_T<S,to_S,from_S>::interceptor_param (
    Dynamic::Parameter & p
  )
{
  p.argument <<= from_S (this->x_);
  p.mode = CORBA::PARAM_OUT;
}

// ============================================================

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::Ret_Special_Basic_Argument_T<S,to_S,from_S>::demarshal (
    TAO_InputCDR & cdr
  )
{
  return cdr >> to_S (this->x_);
}

template<typename S, typename to_S, typename from_S>
void
TAO::Ret_Special_Basic_Argument_T<S,to_S,from_S>::interceptor_result (
    CORBA::Any * any
  )
{
  (*any) <<= from_S (this->x_);
}

#endif /* TAO_SPECIAL_BASIC_ARGUMENT_T_C */

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/tao/Special_Basic_Argument_T.cpp <==
// Special_Basic_Argument_T.cpp,v 1.3 2004/08/06 18:27:58 parsons Exp

#ifndef TAO_SPECIAL_BASIC_ARGUMENT_T_C
#define TAO_SPECIAL_BASIC_ARGUMENT_T_C

#include "tao/Special_Basic_Argument_T.h"
#include "tao/Dynamic_ParameterC.h"

#if !defined (__ACE_INLINE__)
#include "tao/Special_Basic_Argument_T.inl"
#endif /* __ACE_INLINE__ */

ACE_RCSID (tao,
           Special_Basic_Argument_T,
           "Special_Basic_Argument_T.cpp,v 1.3 2004/08/06 18:27:58 parsons Exp")

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::In_Special_Basic_Argument_T<S,to_S,from_S>::marshal (TAO_OutputCDR & cdr)
{
  return cdr << from_S (this->x_);
}

#if TAO_HAS_INTERCEPTORS == 1

template<typename S, typename to_S, typename from_S>
void
TAO::In_Special_Basic_Argument_T<S,to_S,from_S>::interceptor_param (
    Dynamic::Parameter & p
  )
{
  p.argument <<= from_S (this->x_);
  p.mode = CORBA::PARAM_IN;
}

#endif /* TAO_HAS_INTERCEPTORS */

// ===========================================================

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::Inout_Special_Basic_Argument_T<S,to_S,from_S>::marshal (
    TAO_OutputCDR & cdr
  )
{
  return cdr << from_S (this->x_);
}

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::Inout_Special_Basic_Argument_T<S,to_S,from_S>::demarshal (
    TAO_InputCDR & cdr
  )
{
  return cdr >> to_S (this->x_);
}

#if TAO_HAS_INTERCEPTORS == 1

template<typename S, typename to_S, typename from_S>
void
TAO::Inout_Special_Basic_Argument_T<S,to_S,from_S>::interceptor_param (
    Dynamic::Parameter & p
  )
{
  p.argument <<= from_S (this->x_);
  p.mode = CORBA::PARAM_INOUT;
}

#endif /* TAO_HAS_INTERCEPTORS */

// ==============================================================

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::Out_Special_Basic_Argument_T<S,to_S,from_S>::demarshal (
    TAO_InputCDR & cdr
  )
{
  return cdr >> to_S (this->x_);
}

#if TAO_HAS_INTERCEPTORS == 1

template<typename S, typename to_S, typename from_S>
void
TAO::Out_Special_Basic_Argument_T<S,to_S,from_S>::interceptor_param (
    Dynamic::Parameter & p
  )
{
  p.argument <<= from_S (this->x_);
  p.mode = CORBA::PARAM_OUT;
}

#endif /* TAO_HAS_INTERCEPTORS */

// ============================================================

template<typename S, typename to_S, typename from_S>
CORBA::Boolean
TAO::Ret_Special_Basic_Argument_T<S,to_S,from_S>::demarshal (
    TAO_InputCDR & cdr
  )
{
  return cdr >> to_S (this->x_);
}

#if TAO_HAS_INTERCEPTORS == 1

template<typename S, typename to_S, typename from_S>
void
TAO::Ret_Special_Basic_Argument_T<S,to_S,from_S>::interceptor_result (
    CORBA::Any * any
  )
{
  (*any) <<= from_S (this->x_);
}

#endif /* TAO_HAS_INTERCEPTORS */

#endif /* TAO_SPECIAL_BASIC_ARGUMENT_T_C */
